****************************************************************************
*********      MODULE 1 - THEME 2 - ANALYZING TARIFF PROFILES       ******** 
****************************************************************************

* Objective: compute the tariff profile of the Philippines 2008.

* Data source: Bound Concessions, Tariff and Trade details available at wits.worldbank.org/witsweb
*		   or at http://tao.wto.org

* Data used: 	DutyDetails_TL.txt; TradeDetails_TL.txt; TariffDetails_TL.txt; 
*			Concessions_CO.txt; 
*			HS96Complete.dta; ProdGrp_hs96at6dig.dta;
*			ProdGrp_hs07at6dig.dta;
*
* Data save:	Summary.dta; 
*			Freq.dta; 
*			ProductGroups.dta; 
*			Suppliers.dta;
*

********* PRELIMINARY STEP *********
* Set memory and path 
	clear all
	set mem 300m
	set matsize 800
	graph drop _all


	
* Open database
	
	cd "$input/Chapter2/Datasets"

* 1.	Preliminaries
* a)	Download bound and applied tariffs and imports for the Philippines / 2008
* 	at the national tariff line level from the WTO's TAO website. 
* b)	Import the data into STATA, import the relevant HS nomenclatures and 
*	create three dummy variables: one indicating whether the line is bound 
*	or not, one indicating whether the product is agricultural or non-agricultural
*	and one indicating whether the duty is ad valorem or not.

********* IMPORT DATABASE *********

* Import the files from TAO/DIB (txt files) into Stata 
* Note that for Bounds data there might be observations that are shifted
* to the next line. We provide a do-file that corrects this import-related
* issue. 

	* Import the MFN applied and bound tariff rates for PHL
	foreach grp in ag nag {
		foreach file in DutyDetails TradeDetails TariffDetails {
			insheet using "PHL08_`grp'_`file'_TL.txt", clear tab names
			*insheet using "PHL08_`grp'_`file'_TL.csv", clear names
			sort tl
			save "PHL_`grp'_`file'.dta", replace
		}
			
		* Convert all variables in string to allow appending later and avoid issues
		* The scalar variables will be re-transformed later.
		insheet using "PHL_`grp'_Concession_CO.txt", clear tab names
		tostring _all, replace force
		save "PHL_`grp'_Bounds.dta", replace
	}	
	
	* Append the agricultural and non-agricultural datasets
	foreach file in DutyDetails TradeDetails TariffDetails Bounds{
		use "PHL_nag_`file'.dta", clear
		append using "PHL_ag_`file'.dta"
		
	* Check for potential duplicates
		duplicates drop
		sort tl
		save "PHL_`file'.dta", replace
	}



* Reimport the bounds data in csv form if it failed to import all the information. 
* In any case the data MUST NOT be sorted prior the correction of shifted observation
	foreach grp in ag nag {
		*insheet using "PHL_`grp'_Concession_CO.txt", clear tab names
		insheet using "PHL_`grp'_Concession_CO.csv", clear comma names
		gen agr = "`grp'"
		save "PHL_`grp'_Bounds.dta", replace
	}

* It is import not to sort the data but keep the order of the original file.
	use "PHL_ag_Bounds.dta", clear
	append using "PHL_nag_Bounds.dta", force
	duplicates drop
	
*	do "$input/Chapter2/Exercises/1_tariff profile/CorrectedshiftedData.do"
	

*******************************************	
	
*	CorrectedshiftedData
	
* THIS PART OF THE DO-FILE CORRECTS THE IMPORT OF BOUND DATA WHEN SOME OBSERVATIONS ARE SHIFTED
* DU TO THE PRESENCE OF ";" OR ":" IN THE DESCRIPTION OF THE PRODUCT LINE. 
* FOR INSTANCE: A PRODUCT LINE IS SPLIT IN TWO OBSERVATIONS. OBS 10 AND 11, WHERE 
* OBS 11 INCLUDES THE VARIABLES THAT SHOULD BE IN OBS 10 BUT WITH WRONG VARIABLE
* NAMES

* IMPORTANT: ALWAYS MAKE SURE THAT WHEN IMPORTING DATA ON BOUNDS DATA, THE WHOLE
* SAMPLE IS IMPORTED. IF IT IS NOT THE CASE, TWO POSSIBILITIES:
* - OPEN THE TXT.FILE IN EXCEL AND SAVE THE TXT.FILE IN CSV FORM
* - OPEN THE TXT.FILE IN EXCEL AND DROP THE FIRST VARIABLE NAME QUERYNAME.

* The Bound Data files has to be openned to run smoothly the code.

* Note that the first line of the shifted observation is actually the
* lagged number id, e.g. obs 10 begins and ends in obs 11. So once renamed
* correctly obs 11 is actually obs 10. Because the data is shifted, most 
* scalar are now string. But Stata does not allow tom merge two 
* variables with the same name but one in string the other in scalar. So
* we first have to treat all variables as string.
	quietly tostring _all, replace force

* drop the lines where there is no information
	drop if basenomenclature == ""

* Create a variable with the number of strings for basenomenclature.
* If there is no problem with the data it should be 22 (e.g. Harmonized System 1996)
	gen lengthname = length(basenomenclature)

* Create the identifier for each observation, WITHOUT sorting the data
	gen id = _n
	save "Bndstemp.dta", replace

* Consider the shifted observations and use a loop to rename the variables
* accordingly. The use of the loop is to avoid reproducing the same command
* for all the variables. 
	keep if lengthname ~= 22
	global varnames "basenomenclature productclassification reportercode reporter year productdescription productcode tl tls ex certified source bounddutyav bounddutyother bounddutynature boundnaturedescription bounddutybindingstatus bounddutybindingcoverage boundbindingdescription odcdutyav odcdutyother odcdutynature odcdutynaturedescription odcdutybindingstatus odcdutybindingcoverage odcbindingdescription odctextualinformation basedutyav basedutyother basedutynature basenaturedescription basedutybindingstatus basedutybindingcoverage basebindingdescription specialsafeguard  presentinstrument  presentinrtext  implementationfrom  implementationto  recordstatus"
	foreach var of global varnames {
		rename `var' `var'_
	}

* Drop useless variables
	drop  presentinstrument_ presentinrtext_ implementationfrom_ implementationto_ recordstatus_ firstinstrument earlierinrtext 

* Rename the shifted variables with their true name.
* The loop includes an if condition to rename a variable only once.
	global shift1 "basenomenclature productclassification reportercode reporter year productdescription productcode tl tls ex certified source bounddutyav bounddutyother bounddutynature boundnaturedescription bounddutybindingstatus bounddutybindingcoverage boundbindingdescription odcdutyav odcdutyother odcdutynature odcdutynaturedescription odcdutybindingstatus odcdutybindingcoverage odcbindingdescription odctextualinformation basedutyav basedutyother basedutynature basenaturedescription basedutybindingstatus basedutybindingcoverage basebindingdescription specialsafeguard"
	global shift2 "productcode tl tls ex certified source bounddutyav bounddutyother bounddutynature boundnaturedescription bounddutybindingstatus bounddutybindingcoverage boundbindingdescription odcdutyav odcdutyother odcdutynature odcdutynaturedescription odcdutybindingstatus odcdutybindingcoverage odcbindingdescription odctextualinformation basedutyav basedutyother basedutynature basenaturedescription basedutybindingstatus basedutybindingcoverage basebindingdescription specialsafeguard  presentinstrument  presentinrtext  implementationfrom  implementationto  recordstatus firstinstrument"
	scalar s_1 = 0
	foreach s1 of global shift1 {
		scalar s_1 = s_1 + 1
		scalar s_2 = 0
		foreach s2 of global shift2 {
			scalar s_2 = s_2 + 1
			if s_1 == s_2 {
				rename `s1'_ `s2'  
			}
		}
	}

	sort id
	save "ShiftedData.dta", replace

* This file with shifted data has to be appended with the original file
	use "Bndstemp.dta", clear
	drop if lengthname ~= 22
	append using "ShiftedData.dta"

* Make some adjustments
	drop productdescription
	replace basenomenclature = "Harmonized System 1996"
	
	levelsof reportercode
	replace reportercode = `r(levels)'
	
	levelsof reporter
	replace reporter = `r(levels)'
	
	replace year = "1998"
	replace productclassification = "HS - WTO Agricultural Products Definition" if agr == "ag" & productclassification  == ""
	replace productclassification = "HS - WTO  Non-agricultural Products Definition" if agr == "nag" & productclassification  == ""  

	drop if tl == ""
	replace queryname = "" if queryname ~= ""
	format queryname %12s
	drop agr lengthname
	sort id
	drop id 

* Destring the numerical variable
	destring  bounddutyav odcdutyav basedutyav  implementationfrom implementationto , replace

* Erase the temporary files
	erase "Bndstemp.dta"
	erase "ShiftedData.dta"
*******************************************
	
	
	save "PHL_Bounds.dta", replace


********************************************************************
******       Tariff and Imports: Summary and duty ranges      ****** 
********************************************************************
* 2.	Summary and duty ranges of tariff and imports:
* a)	Report in a table the simple average final bound, average MFN applied, 
*	trade weighted average and total imports in billion US$. Do the same 
*	for agricultural and non-agricultural products.

***** Simple average final bound ***** 
	use "PHL_Bounds.dta", clear
	drop if tls == "'00'"

* Create a dummy to distinguish between agriculture and non-agricultural
* products
	gen ag = 0 if productclassification == "HS - WTO  Non-agricultural Products Definition"
	replace ag = 1 if productclassification == "HS - WTO Agricultural Products Definition"
	label var ag "1 if agricultural product"

* Create the hs6 classification based on hs8 (tl)
* Note that for some tariff lines, there are sub-groups to the hs8
* classification (10 digit level)
	gen hs6 = substr(tl,1,6+1) + "'"

* Create a dummy for non ad-valorem duty (== "Specific duty" | == "Mixed duty" | == "Compound duty" | == "Technical duty")
	gen nav = 0
	replace nav = 1 if bounddutynature ~= "A"
	label var nav "1 if non ad-valorem duty"

* Import the full classification at the hs6 level
	sort hs6 ag
	merge hs6 ag using "HS02Complete.dta"
	drop _merge

* Consider only the variables used and save the file
	keep tl tls ex bounddutyav bounddutybindingstatus nav hs6 ag 
	save "PHL_Bounds.dta", replace
 
* Compute the simple (hs sub-heading) average final bound. But first, 
* pre-aggregate at the hs-6 level
* Note that in Stata if there is a missing value for NAV, it is considered as zero when
* the data is collapsed. To avoid this issue, we need to drop the missing values that
* are NAV observations. As a consequence the NAV share have to be compute in a different file.
	use "PHL_Bounds.dta", clear
	drop if bounddutyav == . & nav ~= .
	drop if bounddutybindingstatus ~= "B" 

	collapse(mean) bounddutyav, by(tl hs6 ag )
	collapse(mean) bounddutyav, by(hs6 ag )
	
	egen Total = mean(bounddutyav)
	egen Ag = mean(bounddutyav) if ag == 1
	egen NonAg = mean(bounddutyav) if ag == 0

* Save the results and export them in txt file, but drops duplicates
	collapse(max) Total Ag NonAg 
	label var Total "Simple average final bound Total"
	label var Ag "Simple average final bound Agricultural"
	label var NonAg "Simple average final bound Non-Agricultural"

	gen Summary = "Simple average final bound"	
	order Summary Total Ag NonAg
	save "PHL_Bounds_avg.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_Bounds_avg.txt", replace
	cd "$input/Chapter2/Datasets"


* b)	Determine the binding coverage in total and in agriculture products.

* Compute the binding coverage 
	use "PHL_Bounds.dta", clear
	drop if tls == "'00'"
	replace nav = -999 if bounddutyav == . & nav == .

	gen bind = 1
	replace bind = 0 if bounddutybindingstatus ~= "B"

	collapse(mean) bounddutyav nav bind, by(tl hs6 ag)
	collapse(mean) bounddutyav nav bind, by(hs6 ag)

	egen binding = sum(bind)
	gen toths6 = _N
 	gen BindingCoverage = binding / toths6  * 100 

	bys ag: egen binding_byag = sum(bind)
	bys ag: gen toths6_byag = _N 
	bys ag: gen BindingCoverageNAg  = binding_byag / toths6_byag * 100 if ag == 0 


* c)	Determine the share of non ad valorem duties overall and for non 
*	agricultural products

* Compute the share of non ad-valorem duties.
	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl * 100
	label var TotalNAVshare "Total share of non ad-valorem duty"

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1

	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0

* Save the results and export them in txt file, but drops duplicates.
* Note that the results for Coverage and NAV are saved in 2 different files
	collapse(max) BindingCoverage BindingCoverageNAg  TotalNAVshare TotalNAV_Agshare  TotalNAV_NonAgshare 
	save "PHL_Bounds_coverage.dta", replace

	* Results for NAV
	keep Total*
	rename TotalNAVshare Total
	label var  Total "Total share of non ad-valorem duty in bound duty"
	rename TotalNAV_Agshare Ag
	label var Ag "Total share of non ad-valorem duty in bound duty for Agricultural products"
	rename TotalNAV_NonAgshare NonAg
	label var NonAg "Total share of non ad-valorem duty in bound duty for non-Agricultural products"
	gen Summary = "Share of non ad-valorem duty in bound duty"
	order Summary Total Ag NonAg
	save "PHL_Bounds_NAV_share.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_Bounds_NAV_share.txt", replace
	cd "$input/Chapter2/Datasets"

	* Results for Coverage
	use "PHL_Bounds_coverage.dta", clear
	keep Binding*
	rename BindingCoverage Total 
	label var Total "Binding coverage"
	rename BindingCoverageNAg NonAg 
	label var NonAg "Binding coverage Non-Agricultural"
	gen Summary = "Binding coverage"
	save "PHL_Bounds_coverage.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_Bounds_coverage.txt", replace
	cd "$input/Chapter2/Datasets"

***** Simple average MFN applied ***** 

* Open the database
	use "PHL_DutyDetails.dta", clear
		
	* For some tariff lines at 8 digit there are sub-products given
	* by tls with '00', '01', '02', ..., where '00' is the average
	* of the sub-products. So they have to be dropped to compute
	* the average:
	drop if tls == "'00'"
	keep if nationaldescription == "MFN applied duty rates"

* Create dummy to distinguish between agriculture and non-agricultural
* products 
	gen ag = 0 if classification == "HS - WTO  Non-agricultural Products Definition"
	replace ag = 1 if classification == "HS - WTO Agricultural Products Definition"
	label var ag "1 if agricultural product"

* Create a dummy for non ad-valorem duties (== "Specific duty" | == "Mixed duty")
	gen nav = 0
	replace nav = 1 if description3 ~= "Ad valorem duty"
	label var nav "1 if non ad-valorem duty"

* The data uses harmonized system nomenclature 2007
* Create the hs6 classification based on hs8 (tl)
	gen hs6 = substr(tl,1,6+1) + "'"

* Save the file to be used to compute the trade weighted MFN duties at a later
* stage
	sort tl ag
	save "PHL_MFN.dta", replace

* Compute the average for the HS6 sub-heading by first pre-aggregating at 6-digit level
	use "PHL_MFN.dta", clear

	drop if avdutyrate == . & nav ~= .
	collapse(mean) avdutyrate nav, by(hs6 ag)
	label var avdutyrate "Simple average tariff lines, dutiable or duty-free items"

	egen Total = mean( avdutyrate)
	egen Ag = mean( avdutyrate) if ag == 1
	egen NonAg = mean( avdutyrate) if ag == 0

* Save the average and the share in two files and export the results to a table,
* but first drop duplicates
	collapse(max) Total Ag NonAg 
	label var Total "Simple average MFN applied Total"
	label var Ag "Simple average MFN applied Agricultural"
	label var NonAg "Simple average MFN applied Non-Agricultural"
	gen Summary = "Simple average MFN applied"	

	order Summary Total Ag NonAg
	save "PHL_MFN_avg.dta", replace

* c)	Determine the share of non ad valorem duties overall and for non 
*	agricultural products
* Compute the share of non ad-valorem duties.
	use "PHL_MFN.dta", clear

	sort hs6 ag
	merge hs6 ag using "HS07Complete.dta"
	drop _merge
	replace nav = -999 if avdutyrate == . & nav == .

	collapse(mean) avdutyrate nav, by(tl hs6 ag)
	collapse(mean) avdutyrate nav, by(hs6 ag)

	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl
	label var TotalNAVshare "Total share of non ad-valorem duty"

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1

	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0


* Save the average and the share in two files and export the results to a table, 
* but first drop duplicates
	rename TotalNAVshare Total
	rename TotalNAV_Agshare Ag
	rename TotalNAV_NonAgshare NonAg
	collapse(max) Total Ag NonAg 
	gen Summary = "Share of non ad-valorem duty in MFN applied"
	save "PHL_MFN_NAV_share.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_MFN_NAV_share.txt", replace
	cd "$input/Chapter2/Datasets"
	

***** Trade weighted average MFN applied ***** 
*****     and Imports in billion US$     ***** 
* Compute the trade weighted average for the HS sub-heading
* Note that the imports and weighted average are computed by
* tariff line and not by HS-6 sub-heading


* First, prepare the import data to be merged by considering only total
* imports
	use "PHL_TradeDetails.dta", clear
	keep tl name value 
	keep if name == "All Origins"
	label var value "import values"
	sort tl
	save "PHL_Imp.dta", replace

* Aggregate the sub-products at hs8
	use "PHL_MFN.dta", clear
	collapse(mean) avdutyrate nav, by(tl hs6 ag)

* Merge the duty data with trade details file in order to compute the trade weighted 
* average. Consider only total imports for "All Origins" and the average at the hs6 
* level
	sort tl
	merge tl using "PHL_Imp.dta"
	keep if _merge == 3
	drop _merge
	sort hs6
	save "PHL_MFN_trade.dta", replace

* Aggregate at the HS6-subheading. Note that in TAO they compute
* by tariff lines and not by HS sub-headings
	collapse (mean) avdutyrate nav (sum) value, by(hs6 ag)
	label var avdutyrate "Simple average tariff lines, dutiable or duty-free items"
	label var ag "1 if agricultural product"
	label var value "imports value"
	label var nav "1 if non ad-valorem duty"

	*replace nav = 0 if nav < 1

	egen Mtot = total(value) 
	egen MtotAg = total(value) if ag == 1
	egen MtotNonAg = total(value) if ag == 0
	egen Total = total( (avdutyrate * value)/Mtot )
	egen Ag = total( (avdutyrate * value)/MtotAg ) if ag == 1
	egen NonAg = total( (avdutyrate * value)/MtotNonAg ) if ag == 0

* Save the file and export the results to a table, but first drop duplicates 
	collapse(max) Total Ag NonAg Mtot MtotAg MtotNonAg
	replace Mtot = Mtot / 1000000
	replace MtotAg = MtotAg / 1000000
	replace MtotNonAg = MtotNonAg / 1000000

	label var Total "Trade weighted average MFN applied Total"
	label var Ag "Trade weighted average MFN applied Agricultural"
	label var NonAg "Trade weighted average MFN applied Non-Agricultural"
	save "PHL_MFN_trade_avg.dta", replace

* Report results for trade-weighted average and imports in two different lines
	keep M*
	rename Mtot Total
	rename MtotAg Ag
	rename MtotNonAg NonAg
	gen Summary = "Imports in billion US$"
	order Summary Total Ag NonAg
	save "temp.dta", replace

	use "PHL_MFN_trade_avg.dta", clear
	keep Total Ag NonAg
	gen Summary = "Trade weighted average MFN applied"
	order Summary Total Ag NonAg
	append using "temp.dta"
	erase "temp.dta"
	save "PHL_MFN_trade_avg.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_MFN_trade_avg.txt", replace
	cd "$input/Chapter2/Datasets"
	

* c)	Determine the share of non ad valorem duties overall and for non 
*	agricultural products

* Compute the share of non ad-valorem duties.
	use "PHL_MFN_trade.dta", clear
	replace nav = -999 if avdutyrate == . & nav == .
	collapse(mean) avdutyrate nav, by(hs6 ag)

	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl
	label var TotalNAVshare "Total share of non ad-valorem duty"

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1

	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0

* Save file and export the results to a table, but first drop duplicates 
	rename TotalNAVshare Total
	rename TotalNAV_Agshare Ag
	rename TotalNAV_NonAgshare NonAg
	collapse(max) Total Ag NonAg 
	gen Summary = "Share of non ad-valorem duty in Imports"
	save "PHL_MFN_trade_NAV_share.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_MFN_trade_NAV_share.txt", replace
	cd "$input/Chapter2/Datasets"
	
	
* Create a table with the results
	use "PHL_Bounds_avg.dta", clear
	append using "PHL_Bounds_NAV_share.dta"
	append using "PHL_MFN_avg.dta"
	append using "PHL_MFN_NAV_share.dta"
	append using "PHL_MFN_trade_avg.dta"
	append using "PHL_MFN_trade_NAV_share.dta"
	save "PHL_summary.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_summary.txt", replace
	cd "$input/Chapter2/Datasets"
	


* d)	Determine the frequency distribution of bound and applied duties as 
*	well as imports for agriculture and non-agriculture products. The 
*	following ranges are considered: duty free, 0<=5; 5<=10; 10<=15; 
*	15<= 25; 25<= 50; 50<=100, >100.

***** Frequency distribution ***** 
* The frequency distribution is based on the complete classification, which
* was merged previously. In the TAO, the frequency is computed at the 
* tariff line available in the file while in the table it is at the hs6 level 

***** Final Bound ***** 
	use "PHL_Bounds.dta", clear
	drop if tls == "'00'"

* Create the range for the frequency distribution
	gen range = "Duty-free" if bounddutyav == 0
	replace range = "0 <= 5" if bounddutyav > 0 & bounddutyav <= 5
	replace range = "5 <= 10" if bounddutyav > 5 & bounddutyav <= 10
	replace range = "10 <= 15" if bounddutyav > 10 & bounddutyav <= 15
	replace range = "15 <= 25" if bounddutyav > 15 & bounddutyav <= 25
	replace range = "25 <= 50" if bounddutyav > 25 & bounddutyav <= 50
	replace range = "50 <= 100" if bounddutyav > 50 & bounddutyav <= 100
	replace range = "> 100" if bounddutyav > 100
	replace range = "N.A." if bounddutyav == . 

* Compute the frequency distribution
	collapse (mean) bounddutyav , by(range hs6 tl ag)
	*collapse (mean) bounddutyav , by(range hs6 ag)
	bys ag: gen nrbnd = _N 
	bys range ag: gen freqbnd = _N 
	gen freqBndAg = freqbnd / nrbnd *100 if ag == 1
	gen freqBndNonAg = freqbnd / nrbnd *100 if ag == 0

* Drop the duplicates and save the file
	collapse(max) fre*Ag, by(range)
	label var range "Distribution range" 
	label var freqBndAg "Frequency distribution for applied bound duty in agricultural products"
	label var freqBndNonAg "Frequeency distribution for applied bound duty in non-agricultural products"
	sort range
	save "PHL_BND_freq.dta", replace


***** MFN applied ***** 
	use "PHL_MFN.dta", clear
	drop if basenomenclature == ""	

* Pre-aggregate the data at 8-digits
	collapse (mean) avdutyrate nav, by(tl hs6 ag)

* Merge with the full classification 
	sort hs6
	merge hs6 using "ProdGrp_hs07at6dig.dta"

* Create the range for the frequency distribution
	gen range = "Duty-free" if avdutyrate == 0
	replace range = "0 <= 5" if avdutyrate > 0 & avdutyrate <= 5
	replace range = "5 <= 10" if avdutyrate > 5 & avdutyrate <= 10
	replace range = "10 <= 15" if avdutyrate > 10 & avdutyrate <= 15
	replace range = "15 <= 25" if avdutyrate > 15 & avdutyrate <= 25
	replace range = "25 <= 50" if avdutyrate > 25 & avdutyrate <= 50
	replace range = "50 <= 100" if avdutyrate > 50 & avdutyrate <= 100
	replace range = "> 100" if avdutyrate > 100
	replace range = "NAV" if nav == 1
	replace range = "N.A." if avdutyrate == . & nav == .

* Compute the frequency in % of the number of tariff lines
	collapse (mean) avdutyrate , by(range tl ag)
	bys ag: gen nrduty = _N
	bys range ag: gen freqduty = _N 
	gen freqAg = freqduty / nrduty *100 if ag == 1
	gen freqNonAg = freqduty / nrduty *100 if ag == 0

* Save the results
	collapse(max) fre*Ag, by(range)
	label var range "Distribution range" 
 	label var freqAg "Frequency distribution for applied MFN duty in agricultural products"
	label var freqNonAg "Frequency distribution for applied MFN duty in non-agricultural products"
	sort range
	save "PHL_MFN_freq.dta", replace


***** Imports ***** 
* Open the file which was already merged trade and duties data
	use "PHL_MFN_trade.dta", clear
	drop if name == ""	
	collapse (sum) value (mean) avdutyrate nav , by(tl hs6 ag)

* Create the range for the frequency distribution
	gen range = "Duty-free" if avdutyrate == 0
	replace range = "0 <= 5" if avdutyrate > 0 & avdutyrate <= 5
	replace range = "5 <= 10" if avdutyrate > 5 & avdutyrate <= 10
	replace range = "10 <= 15" if avdutyrate > 10 & avdutyrate <= 15
	replace range = "15 <= 25" if avdutyrate > 15 & avdutyrate <= 25
	replace range = "25 <= 50" if avdutyrate > 25 & avdutyrate <= 50
	replace range = "50 <= 100" if avdutyrate > 50 & avdutyrate <= 100
	replace range = "> 100" if avdutyrate > 100
	replace range = "NAV" if nav == 1
	replace range = "N.A." if avdutyrate == . & nav == .

* Compute the frequency
	drop if value == .
	collapse (sum) value, by(range hs6 ag)
	bys ag: egen Mtot = total(value)
	bys ag range: egen Mtotrg = total(value)
	gen freqMAg = Mtotrg /Mtot * 100 if ag == 1
	gen freqMNonAg = Mtotrg /Mtot * 100 if ag == 0

* Save the file
	collapse(max) freq*Ag, by(range)
	label var range "Distribution range" 
	label var freqMAg "Frequency distribution for imports in agricultural products"
	label var freqMNonAg "Frequency distribution for imports in agricultural products"
	sort range 
	save "PHL_Imp_freq.dta", replace


***** Create a table with the results ***** 
* Merge the different files to create one single table
	clear
	set obs 10
	gen id = _n
	gen range = "Duty-free" if id == 1
	replace range = "0 <= 5" if id == 2
	replace range = "5 <= 10" if id == 3
	replace range = "10 <= 15" if id == 4
	replace range = "15 <= 25" if id == 5
	replace range = "25 <= 50" if id == 6
	replace range = "50 <= 100" if id == 7
	replace range = "> 100" if id == 8
	replace range = "N.A." if id == 9
	replace range = "NAV" if id == 10

	sort range
	merge range using "PHL_BND_freq.dta"
	drop _merge
	sort range
	merge range using "PHL_MFN_freq.dta"
	drop _merge
	sort range
	merge range using "PHL_IMP_freq.dta"
	drop _merge
	sort id

	foreach var in freqBndAg freqBndNonAg freqAg freqNonAg freqMAg freqMNonAg {
		replace `var' = 0 if `var' == .
	}
	drop if range == "N.A."

* Save the file and export the results into a table
	label var range "Distribution range" 
	label var freqBndAg "Frequency distribution for applied bound duty in agricultural products"
	label var freqBndNonAg "Frequeency distribution for applied bound duty in non-agricultural products"
 	label var freqAg "Frequency distribution for applied MFN duty in agricultural products"
	label var freqNonAg "Frequency distribution for applied MFN duty in non-agricultural products"
	label var freqMAg "Frequency distribution for imports in agricultural products"
	label var freqMNonAg "Frequency distribution for imports in agricultural products"
	save "PHL_freq.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL__freq.txt", replace
	cd "$input/Chapter2/Datasets"


********************************************************************
******          Tariff and Imports py product groups          ****** 
********************************************************************
* 3.	Tariff and Imports by product groups
* a)	For each product group (10 agriculture and 12 non-agriculture groups), 
*	determine the simple average of the final bound and MFN applied duties. 
*	Compute the share of duty-free six-digit subheadings in the total number
*	of subheadings in the product group for bound and MFN tariffs. Determine
*	the highest ad valorem duty within the product group for both tariffs. 
*	In addition, for bound duties, compute the share of bound HS six-digit 
*	subheadings containing at least one bound tariff line.

***** Final Bound ***** 
* Open the file
	use "PHL_Bounds.dta", clear
	drop if tls == "'00'"

* Merge with the nomenclature file which includes the products group definition
	sort hs6 ag
	merge hs6 ag using "ProdGrp_hs02at6dig.dta"
	drop _merge
	save "Bounds_PHL.dta", replace

* Compute the average and maximum rate of bound duty but first aggregate at the hs 
* 6-digits for the mean. Note that missing values are considered as zero with
* collapse, so the should be discarded to compute the mean
	use "Bounds_PHL.dta", clear
	drop if bounddutybindingstatus ~= "B"
	drop if bounddutyav == .
	bys grpname: egen maxbndduty = max(bounddutyav)
	collapse(mean) bounddutyav maxbndduty, by(tl hs6 ag grpname)
	collapse(mean) bounddutyav maxbndduty, by(hs6 ag grpname)
	bys grpname: egen avbndduty = mean(bounddutyav)
	label var avbndduty "Average final bound duties by product group"
	label var maxbndduty "Max final bound duties by product group"
	sort ag grpname
	save "Bounds_PHL_byprod.dta", replace

* Compute the number of duty-free after the pre-aggreagtion
	use "Bounds_PHL.dta", clear
	gen dutyfree = 0
	replace dutyfree = 1 if bounddutyav == 0

	gen bind = 1
	replace bind = 0 if bounddutybindingstatus ~= "B"

	collapse(mean) bounddutyav nav dutyfree bind nrhs6, by(tl hs6 ag grpname)
	collapse(mean) bounddutyav nav dutyfree bind nrhs6, by(hs6 ag grpname)

	bys grpname: egen nrdutyfree = sum(dutyfree)
	bys grpname: gen lines = _N
	bys grpname: gen shbnddutyfree = nrdutyfree / lines * 100
	label var grpname "Share of duty-free in final bound duties by product group"

* compute the binding coverage
	bys grpname: egen totbind = sum(bind)
	bys grpname: gen binding = totbind / lines * 100
	label var binding "Binding coverage by product"

* Compute the NAV share
	bys grpname: egen totnav = sum(nav)
	bys grpname: gen navshare = totnav / nrhs6 * 100
	label var navshare "Share of NAV in final bound duties by product group"

* Merge with the average and max results to create a single table
	sort ag grpname
	merge ag grpname using "Bounds_PHL_byprod.dta"

* Save the results
	collapse(max) avbndduty maxbndduty shbnddutyfree binding navshare, by(grpname ag)
	gsort -ag grpname
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_Bounds_byprod.txt", replace
	cd "$input/Chapter2/Datasets"

	label var avbndduty "Average final bound duties by product group"
	label var maxbndduty "Max final bound duties by product group"
	label var shbnddutyfree "Share of duty-free in final bound duties by product group"
	label var binding "Binding coverage by product group"
	label var navshare "Share of NAV in final bound duties by product group"
	sort ag grpname
	save "PHL_Bounds_byprod.dta", replace
	erase "Bounds_PHL.dta"


***** MFN applied ***** 
* Open file
	use "PHL_MFN.dta", clear
	drop if tls == "'00'"
 
* Merge with the nomenclature file which includes the products group definition
	sort hs6 ag
	merge hs6 ag using "ProdGrp_hs07at6dig.dta"
	drop _merge

	gen dutyfree = 0
	replace dutyfree = 1 if avdutyrate == 0
	sort ag grpname
	save "MFN_PHL.dta", replace

* Compute the average and maximum rate of applied MFN duty. Note that missing values are considered as zero when they are 
* collapsed
	use "MFN_PHL.dta", clear
	drop if avdutyrate == .
	bys grpname: egen maxduty = max(avdutyrate)
	collapse(mean) avdutyrate maxduty, by(tl hs6 grpname ag)
	collapse(mean) avdutyrate maxduty, by(hs6 grpname ag)
	bys grpname: egen avduty = mean(avdutyrate)
	label var avduty "Average MFN applied duties by product group"
	label var maxduty "Max MFN applied duties by product group"
	sort ag grpname
	save "MFN_PHL_byprod.dta", replace

* Compute the number of duty-free
	use "MFN_PHL.dta", clear
	collapse(mean) dutyfree nav nrhs6, by(tl hs6 grpname ag)
	collapse(mean) dutyfree nav nrhs6, by(hs6 grpname ag)

	bys grpname: gen lines = _N
	bys grpname: egen nrdutyfree = sum(dutyfree)
	bys grpname: gen shdutyfree = nrdutyfree / lines * 100
	label var shdutyfree "Share of duty-free in MFN applied duties by product group"

* Compute the share of NAV
	bys grpname: egen totnav = sum(nav)
	bys grpname: gen navshare = totnav / nrhs6 * 100	
	label var navshare "Share of NAV in MFN applied duties by product group"

* Merge with the average and max results to create a single table
	sort ag grpname
	merge ag grpname using "MFN_PHL_byprod.dta"

* Save the results
	collapse(max) avduty maxduty shdutyfree navshare, by(grpname ag)
	gsort -ag grpname 
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "MFN_PHL_byprod.txt", replace
	cd "$input/Chapter2/Datasets"

	label var avduty "Average MFN applied duties by product group"
	label var maxduty "Max MFN applied duties by product group"
	label var shdutyfree "Share of duty-free in MFN applied duties by product group"
	label var navshare "Share of NAV in MFN applied duties by product group"
	sort ag grpname
	save "PHL_MFN_byprod.dta", replace


* b)	Compute the share of each product group in total imports. Compute the 
*	share of MFN duty-free imports in total imports for each product group.

***** Imports ***** 
* Open file
	use "PHL_MFN_trade.dta", clear

* Merge with the nomenclature file which includes products group definition
	sort hs6 ag
	merge hs6 ag using "ProdGrp_hs07at6dig.dta"
	drop _merge

	gen dutyfree = 0
	replace dutyfree = 1 if avdutyrate== 0

* Compute the share in total imports 
	collapse(mean) avdutyrate dutyfree nav (sum)value, by(tl hs6 grpname ag)
	egen Mtot = total(value)
	bys grpname: egen Mpro = total(value)
	bys grpname: gen Mshare = Mpro / Mtot * 100
	label var Mshare "Imports share in by product group"

* Compute the share of duty-free
	gen Mdutyfree = value * dutyfree
	bys grpname: egen Mdutyfreepro = sum(Mdutyfree)
	bys grpname: gen Msharedutyfree = Mdutyfreepro / Mpro * 100
	label var Msharedutyfree "Duty-free imports share in by product group"

* Compute the share of NAV
	replace nav = 0 if nav == .
	gen Mnav = value * nav
	bys grpname: egen Mtotnav = sum(Mnav)
	bys grpname: gen Mnavshare = Mtotnav / Mpro * 100
	label var Mnavshare "NAV imports share in by product group"

	collapse(max) Mshare Msharedutyfree Mnavshare, by(grpname ag)
	gsort -ag grpname 
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_MFN_tradebyprod.txt", replace
	cd "$input/Chapter2/Datasets"
	
	label var Mshare "Imports share in by product group"
	label var Msharedutyfree "Duty-free imports share in by product group"
	label var Mnavshare "NAV imports share in by product group"
	sort ag grpname 
	save "PHL_MFN_tradebyprod.dta", replace

***** Create a table with the results ***** 
* Merge the different files to create one single table 
	use "PHL_Bounds_byprod.dta", clear
	sort ag grpname
	merge ag grpname using "PHL_MFN_byprod.dta"
	drop _merge
	sort ag grpname
	merge ag grpname using "PHL_MFN_tradebyprod.dta"
	drop _merge
	gsort -ag grpname 

* Save the file and export the results into a table
	save "PHL_ProductGroups.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_ProductGroups.txt", replace
	cd "$input/Chapter2/Datasets"
	
	erase "Bounds_PHL_byprod.dta"
	erase "MFN_PHL_byprod.dta"


********************************************************************
******        Major Suppliers Partners and Duties Faced       ****** 
********************************************************************

* 4.	Major suppliers and impact of the product mix on the level of duties
* a)	Select the 5 major suppliers of agricultural and non-agricultural products
* 	in terms of total bilateral imports. 

* Open the file
	use "PHL_TradeDetails.dta", clear
	keep classification tl name value 
	drop if name == "All Origins"
	label var value "import values"
	sort tl

* The data uses harmonized system nomenclature 2007
* Create the hs6 classification based on hs8 (tl)
	gen hs6 = substr(tl,1,6+1) + "'"

* Create a dummy to distinguish between agriculture and non-agricultural
* products
	gen ag = 0 if classification == "HS - WTO  Non-agricultural Products Definition"
	replace ag = 1 if classification == "HS - WTO Agricultural Products Definition"
	label var ag "1 if agricultural product"

* Merge bilateral trade with duty rates dataset
	sort tl ag
	joinby tl ag using "PHL_MFN.dta"
	* merge tl ag using "PHL_MFN.dta"
	* drop _merge
	drop if value == .

* Save the file
	order ag tl tls hs6 value avdutyrate
	sort hs6 ag
	save "PHL_Trade.dta", replace

* Determine the major importers, but first adjust for the sub-lines at the 10 digit level
	collapse(mean) value nav, by(tl name ag)
	collapse(sum) value (mean)nav, by(name ag)
	label var value "Total imports by country"
	bys ag : gen N = _N
	gsort ag N -value
	bys ag N: gen n = _n
	gen n1 = n if ag == 1
	gen n0 = n if ag == 0
	keep if n1 <= 5 | n0 <= 5
	gen majmarket = 1
	label var majmarket "Major markets"

* Compute the share of NAV in imports
	bys ag: gen Mnav = value * nav
	bys ag: egen Mtot = total(value)
	bys ag: gen navshare = Mnav / Mtot * 100
	label var navshare "share of NAV in imports by country"

* Save the results
	keep name ag value navshare majmarket
	gsort -ag -value
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using "PHL_ExportsMarkets.txt", replace
	cd "$input/Chapter2/Datasets"
	
	sort name ag
	save "PHL_ExportsMarkets.dta", replace
 


* b)	For each of these suppliers, compute the simple and trade-weighted average
* 	MFN duty based only on tariff lines with imports. Determine the duty-free
* 	imports in terms of tariff lines in percent of all traded tariff lines and
*	in terms of share of duty-free trade in per cent of all bilateral trade 
*	flows.
* Open the database
	use "PHL_Trade.dta", clear
	sort name ag
	merge name ag using "PHL_ExportsMarkets.dta", 
	keep if majmarket == 1
	drop _merge

* Create the subheadings
	gen hs2 = substr(tl,1,2+1) + "'"
	gen hs4 = substr(tl,1,4+1) + "'"

* Save file
	save "PHL_ExportsDiversif.dta", replace

* Compute MFN average of traded tariff lines
	* Adjust for the sub tariff lines
	collapse(mean) avdutyrate value, by(ag name tl hs6)

	* Compute the simple mean
	bys ag name: egen dutybarsimple = mean(avdutyrate)
	label var dutybarsimple "Simple average of trade tariff line"
	
	* Compute the weighted trade average
	bys ag name: egen Mtot = total(value)
	bys ag name: gen dutybarw = avdutyrate*value
	bys ag name: egen dutybarweight = total(dutybarw)
	replace dutybarweight = dutybarweight / Mtot
	label var dutybarweight "Trade weighted average of trade tariff line"

	keep name ag dutybarsimple dutybarweight
	duplicates drop
	sort name ag
	save "PHL_tradedTL.dta", replace

* Compute the duty-free imports
	use "PHL_ExportsDiversif.dta", clear
	gen dutyfree = 0
	replace dutyfree = 1 if avdutyrate == 0

	* Adjust for the tariff lines at the 10 digit level
	collapse(mean) avdutyrate value dutyfree, by(ag name tl hs6)

	* Compute the share of duty free in tariff line
	bys ag name: gen nrlines = _N
	bys ag name: egen nrdutyfree = total(dutyfree)
	gen shdutyfree = nrdutyfree / nrlines * 100
	label var shdutyfree "Share of duty free in total traded tariff lines"

	* Compute the share of duty free in import value
	bys ag name: gen Mduty = value * dutyfree
	bys ag name: egen Mtot = total(value)
	bys ag name: egen Mdutyfree = total(Mduty/Mtot * 100)
	label var Mdutyfree "share of duty free imports in total imports"

	keep ag name shdutyfree Mdutyfree
	duplicates drop
	sort name ag
	save "PHL_Dutyfree.dta", replace


***** Create a table with the results ***** 

* Merge the different tables
	use "PHL_ExportsMarkets.dta", clear
	sort name ag
	merge name ag using "PHL_tradedTL.dta"
	drop _merge
	sort name ag
	merge name ag using "PHL_Dutyfree.dta"
	drop _merge majmarket
	gsort -ag -value

* Save the file and export it
	save "PHL_Suppliers.dta", replace
	
	cd "$input/Chapter2/Exercises/1_tariff profile/Results"
	outsheet using  "PHL_Suppliers.txt", replace
	cd "$input/Chapter2/Datasets"
		


	
*	Erase construction files
	
		foreach grp in ag nag {
	foreach file in DutyDetails TradeDetails TariffDetails {
	erase PHL_`grp'_`file'.dta
	}
	}
*	

	foreach file in 	PHL_MFN.dta  MFN_PHL.dta PHL_ag_Bounds.dta PHL_nag_Bounds.dta PHL_DutyDetails.dta 	///
						PHL_TradeDetails.dta PHL_TariffDetails.dta PHL_Bounds.dta PHL_Bounds_avg.dta 		///
						PHL_Bounds_coverage.dta PHL_Bounds_NAV_share.dta PHL_Imp.dta PHL_MFN_avg.dta  		///
						PHL_MFN_trade.dta  PHL_MFN_trade_avg.dta PHL_summary.dta PHL_BND_freq.dta  			///
						PHL_MFN_freq.dta  PHL_Imp_freq.dta PHL_freq.dta PHL_Trade.dta PHL_Bounds_byprod.dta ///
						PHL_ExportsMarkets.dta PHL_ExportsDiversif.dta PHL_MFN_byprod.dta 					///
						PHL_ProductGroups.dta PHL_tradedTL.dta PHL_Dutyfree.dta   PHL_Suppliers.dta			///
						PHL_MFN_NAV_share.dta PHL_MFN_trade_NAV_share.dta  PHL_MFN_tradebyprod.dta		{
	erase `file'
	}
*
	
exit
exit
exit
