****************************************************************************************
********* MODULE 1 - THEME 2 - AD VALOREM EQUIVALENTS OF NON AD VALOREM TARIFFS ******** 
****************************************************************************************



* Objective: Analyze Ad valorem equivalents of non ad valorem tariffs

* Data source: 	Tariff and Trade details available at wits.worldbank.org
* Data used: 	ag_DutyDetails_TL.txt;  nag_ind_DutyDetails_TL.txt; nag_pet_DutyDetails_TL.txt;
*		   	ag_TradeDetails_TL.txt; nag_ind_TradeDetails_TL.txt; nag_pet_TradeDetails_TL.txt;
	 
* Data saved:	Summary.dta;
*			Freq.dta;
*



********* PRELIMINARY STEP *********
* Set memory and path 
	clear all
	set mem 300m
	set matsize 800
	graph drop _all
	

	

	
* Open database
	
	cd "$input/Chapter2/Datasets"


********* IMPORT DATABASE *********
* do "Chapter2/ImportDataFromWITS-TRAINS.do"
	
* Goal: compare aggregate tariff statistics for South Africa including the ad 
* valorem equivalents of NAV tariffs or not including them.
* source: http://wits.worldbank.org


*********    QUESTIONS    ********* 

* 1. DOWNLOAD 
* a)	Download applied tariffs for South Africa (2008) from WITS. You will need
* 	all different sets of applied tariffs: one set including only ad valorem
* 	tariffs and three sets including ad valorem equivalents of non ad valorem
* 	tariffs estimated using the various methods proposed by WITS (UNCTAD1 and 
*	2 and WTO). Download the import flows.

* b)	Examine the tariff data. Are non ad valorem equivalents provided for all 
*	tariff lines? Which is the nomenclature used for the applied rates?
	

* 2. PRELIMINARIES 
* a)	Before doing any calculations, the data need to be reformatted. If you have
* 	downloaded the applied tariffs in three different files containing respectively
* 	the agricultural lines, the industrial lines and the petroleum lines, you
* 	will need to append these three files.

* Import to Stata the files from WITS/TRAINS (txt files). Note that the WITS, 
* unlike TAO, does allow to select the Agricultural group and two Non-Agricultural 
* groups:  industrial and petrol groups. The other difference is with respect to
* TAO is the actual name of the variables. 
	foreach file in DutyDetails TradeDetails {
		insheet using "ZAF08_ag_`file'_TL.txt", clear names
		save "ZAF_ag_`file'.dta", replace
		foreach grp in nag_ind nag_pet {
			insheet using "ZAF08_`grp'_`file'_TL.txt", clear names
			save "ZAF_`grp'_`file'.dta", replace
		}
	}


* b) 	Create a dummy variable taking the value 1 for agricultural products and zero 
* 	otherwise. The tariff line code is considered by STATA as a scalar and needs 
*	to be converted into a string of characters while the opposite is true for 
*	import data which need to be converted into scalars. 

* Append the agricultural and non-agricultural datasets and create the dummy for
* agricultural and non-agricultural products 
	foreach file in DutyDetails TradeDetails {
		use "ZAF_ag_`file'.dta", clear
		gen ag = 1
		label var ag "1 if agricultural products"
		foreach grp in nag_ind nag_pet {
			append using "ZAF_`grp'_`file'.dta", force
			replace ag = 0 if ag == .
		}

	* The tariff line is treated as a scalar. As a consequence, if the first digit 
	* is zero, it is automatically dropped. The tariff line has to be converted 
	* into strings. Note that for high values (e.g. 99999999) Stata considers the
	* round values (e.g. 1.00e+08) with tostring and string. To avoid this, we use 
	* the levelsof command.
		gen tl = ""
		label var tl "Tariff line"
		format tl %14s
		levelsof productcode, local(code)
		foreach c of local code {
			replace tl = "`c'" if productcode == `c'
		}

		gen nrstring = length(tl)
		replace tl = "0" + tl if nrstring < 8
		replace tl = "'" + tl + "'"

		drop nrstring
		gen nrstring = length(tl)
		keep if nrstring == 8 + 2
		drop nrstring

	* Check for potential duplicates
		duplicates drop
		sort tl
		save "ZAF_`file'_.dta", replace
	}


* The data on imports is read as strings because of the "," delimiter. So we need
* to convert it into scalars.
	use "ZAF_TradeDetails_.dta", clear
	gen value = subinstr(tradevalue000,",","",2)
	destring value, replace 
	label var value "bilateral trade in 000"
	keep reporter year tl partner value ag 
	sort tl
	save "ZAF_TradeDetails.dta", replace

* Consider only applied MFN duty. Note that there is no bound information
* in TRAINS if you select TRAINS - View and Export Raw Data
	use "ZAF_DutyDetails_.dta", clear
	keep if measurename == "MFN duties (Applied)"
	keep year tl ag advalorem estimationmethod 

* Consider the WTO AG method only for agricultural products and WTO NAMA
* only for industrial products
	gen nav = 0 if estimationmethod == ""
	replace nav = 1 if nav == .
	replace nav = . if advalorem == .
	label var nav "1 if non ad-valorem"

	drop if estimationmethod == "WTO Agriculture Method" & ag == 0
	drop if estimationmethod == "WTO NAMA Method" & ag == 1

	replace estimationmethod = "AV" if estimationmethod == "" & advalorem ~= .
	replace estimationmethod = "MISS" if advalorem == .
	replace estimationmethod = "UNCTAD1" if estimationmethod == "UNCTAD Method 1"
	replace estimationmethod = "UNCTAD2" if estimationmethod == "UNCTAD Method 2"
	replace estimationmethod = "WTO" if estimationmethod == "WTO Agriculture Method" | estimationmethod == "WTO NAMA Method"


* c)	Finally, the data need to be reshaped into three columns each containing a set 
* 	of tariffs with ad valorem equivalents calculated using a different method,
* 	plus one without ad valorem equivalents. 

* Reshape the data to have 1 column without NAV, 1 column including missing NAV
* and 3 columns with the different NAV methods.
	reshape wide advalorem, i(year tl nav ag) j(estimationmethod) string

* Make some adjustments
	foreach var in UNCTAD1 UNCTAD2 WTO {
		rename advalorem`var' duty`var'
		replace duty`var' = advaloremAV if advaloremAV ~= .
	}
	rename advaloremAV duty
	label var duty "MFN applied rate without NAV"
	label var dutyUNCTAD1 "MFN applied rates with NAVE according to UNCTAD Method 1"
	label var dutyUNCTAD2 "MFN applied rates with NAVE according to UNCTAD Method 2"
	label var dutyWTO "MFN applied rates with NAVE according to WTO Agriculture Method and NAMA Method"

* To know which nomenclature is used check WITS "Help and Information" -->
* "TRAINS Tariff Measures"
	label var tl "Tariff line in HS 2007"
	keep year tl ag nav duty*
	save "ZAF_DutyDetails.dta", replace


* 3. NAV SHARE & DUTY AVERAGE
* a)	Having done all this, calculate the share of non ad valorem rates at the
*	HS 6 digit level. When only part of the HS 6 digit subheading is subject
* 	to non ad valorem duties, the percentage share of these tariff lines is 
*	used. Calculate the same statistic for agricultural and non agricultural
* 	products.

* Open the dataset
	use "ZAF_DutyDetails.dta", clear
	describe

* The data uses harmonized system nomenclature 2007
* Create the hs6 classification based on hs8 (tl)
	gen hs6 = "'" + substr(tl,2,6) + "'"
	label var hs6 "HS at 6-digit"
	gen hs4 = "'" + substr(tl,2,4) + "'"
	label var hs4 "HS at 4-digit"
	gen hs2 = "'" + substr(tl,2,2) + "'"
	label var hs2 "HS at 2-digit"

* Save the file for the frequency distribution question
	save "ZAF_MFN.dta", replace

* Pre-aggregation at the HS 6 digit
	collapse(mean) duty* nav, by(ag hs6)

* Compute the share of non ad valorem 
	egen nrtl = count(nav)
	egen TotalNAV = sum(nav)
	gen TotalNAVshare = TotalNAV / nrtl * 100

	bys ag: egen nrtl_ag_nag = count(nav)
	egen TotalNAV_Ag = sum(nav) if ag == 1
	gen TotalNAV_Agshare = TotalNAV_Ag / nrtl_ag_nag * 100 if ag == 1
	egen TotalNAV_NonAg = sum(nav) if ag == 0	
	gen TotalNAV_NonAgshare = TotalNAV_NonAg / nrtl_ag_nag * 100 if ag == 0


* b)	Next, for each of the four sets of tariffs compute the simple average of 
*	applied tariffs, first at the HS six-digit level and then overall, for 
*	agricultural and for non agricultural products.  

* Compute the average for the HS6 sub-heading
	foreach type in "" "UNCTAD1" "UNCTAD2" "WTO" {
		egen duty`type'bar = mean(duty`type') 
		label var duty`type'bar "Aggregate tariff lines according to `type' at 6 digit"
		bys ag: egen duty`type'barAgNonAg = mean(duty`type') 
		label var duty`type'barAgNonAg "Simple average tariff lines according to `type'"
	}


* Save file and export the results to a table, but first drop the duplicates
	keep ag duty*bar* *NAV*share
	duplicates drop
	order duty*
	save "Summary.dta", replace
	
	cd "$input/Chapter2/Exercises/2_Ad valorem equivalents of non ad valorem tariffs/Results"   
	outsheet using "Summary.txt", replace
	cd "$input/Chapter2/Datasets"
	


* 4. FREQUENCY DISTRIBUTION OF TARIFF LINES
* a) 	The second part of the exercise consists in computing the frequency distribution
* 	of tariff lines by duty range respectively for agricultural and non agricultural
* 	products. Remember that the shares by duty range in the frequency distribution are
*	based on the pro-rata shares of tariff line level duties in the standard HS 6-digit
* 	subheadings. Start by defining the ranges of your choice, remembering that
* 	tariffs can take high positive values (>100). Include a duty-free category.

* Note: The frequency distribution is computed at the tariff line. TRAINS provides
* all the tariff lines even if there is no applied duty, so technically you do not
* need to merge the file with the full HS nomenclature.
* Open the dataset
	use "ZAF_MFN.dta", clear

* Merge with the full classification although TRAINS should include all the tariff
* lines (even if there is no duty rate)
	* sort hs6
	* merge hs6 using "ProdGrp_hs07at6dig.dta"

* Create the range for the frequency distribution for each duty type
	foreach type in "" "UNCTAD1" "UNCTAD2" "WTO"  {
		gen range`type' = "Duty-free" if duty`type' == 0
		replace range`type' = "0 <= 5" if duty`type' > 0 & duty`type' <= 5
		replace range`type' = "5 <= 10" if duty`type' > 5 & duty`type' <= 10
		replace range`type' = "10 <= 15" if duty`type' > 10 & duty`type' <= 15
		replace range`type' = "15 <= 25" if duty`type' > 15 & duty`type' <= 25
		replace range`type' = "25 <= 50" if duty`type' > 25 & duty`type' <= 50
		replace range`type' = "50 <= 100" if duty`type' > 50 & duty`type' <= 100
		replace range`type' = "> 100" if duty`type' > 100
		replace range`type' = "N.A." if duty`type' == .
	}
	save "ZAF_MFN_range.dta", replace


* b)	Compute the shares and comment.

* Compute the total number of hs 6 digit subheading for agricultural
* and non agricultural products
	keep ag hs6
	duplicates drop
	bys ag: gen totlines = _N
	keep ag totlines 
	duplicates drop
	sort ag 
	save "ZAF_totlines_HS6.dta", replace

* Compute the frequency in % of the number of tariff lines for each duty type. This is
* done by creating a temporary file for each type and then merging
* them together.
	foreach type in "" "UNCTAD1" "UNCTAD2" "WTO"  {
		use "ZAF_MFN_range.dta", replace
		collapse(mean) duty`type', by(ag range`type' hs6)
		*drop if range`type' == "N.A."
		bys ag: gen totduty = _N
		bys range`type' ag: gen nrduty`type' = _N 
		gen freqduty`type' = nrduty`type' / totduty * 100
		label var freqduty`type' "Frequency distribution for MFN applied `type'"  
		gen freqrange = range`type' 
		keep  ag freqrange freqduty`type'
		duplicates drop
		sort ag freqrange 
		save "ZAF_MFN_range`type'_temp.dta", replace
	}
	keep ag freqrange 
	foreach type in "" "UNCTAD1" "UNCTAD2" "WTO"  {
		sort ag freqrange 
		merge ag freqrange using "ZAF_MFN_range`type'_temp.dta"
		drop _merge
		erase "ZAF_MFN_range`type'_temp.dta"
	}

	save "Frequency.dta", replace
	
	cd "$input/Chapter2/Exercises/2_Ad valorem equivalents of non ad valorem tariffs/Results"
	outsheet using "Frequency.txt", replace
	cd "$input/Chapter2/Datasets"
	
	
	foreach file in 	ZAF_MFN.dta	ZAF_ag_DutyDetails.dta ZAF_nag_ind_DutyDetails.dta ZAF_nag_pet_DutyDetails.dta 	///
						ZAF_ag_TradeDetails.dta ZAF_nag_ind_TradeDetails.dta ZAF_nag_pet_TradeDetails.dta 			///
						ZAF_DutyDetails_.dta ZAF_TradeDetails_.dta ZAF_TradeDetails.dta ZAF_DutyDetails.dta 		///
						Summary.dta ZAF_MFN_range.dta  ZAF_totlines_HS6.dta Frequency.dta	{
	erase `file'
	}
*					

